@@ -8,6 +8,8 @@
 #define         ReqConnect      0x01
 #define         Ack             0x02
 #define         Nak             0x03            /* Busy */
+#define		NoRoute		0x04
+#define		RepActive	0x80
 #define         ReqEnd          0xff
 
 
@@ -16,14 +18,24 @@ struct  shm_form {
                                         /* 0x01 リクエスト　    */
                                         /* 0x02 リプライ        */
                                         /* 0x03 未登録          */
-                                        /* 0x04 		*/
+                                        /* 0x04 転送先無し	*/
                                         /* 0xff 削除            */
         char    protocol;
-        char    dstRep[8];
-        char    Rep2Call[8];
-        char    Rep1Call[8];
-        char    dstCall[8];
-        char    srcCall[8];
+
+        union {
+                struct {
+                        char    dstRep[8];
+                        char    Rep2Call[8];
+                        char    Rep1Call[8];
+                        char    dstCall[8];
+                        char    srcCall[8];
+                };
+                struct {
+                        char    rep_name[8];
+                        char    trust_name[16];
+                        char    reserve[16];
+                };
+        };
         in_port_t       srcPort;
         struct  in_addr srcIP;
 	unsigned char	PacketID[2];
