@@ -1,5 +1,7 @@
 #define         _XOPEN_SOURCE
 
+#define	LOGFILE	"/var/log/trust.log"
+
 #include        <stdio.h>
 #include        <stdlib.h>
 #include        <malloc.h>
@@ -19,8 +21,7 @@
 #include        <arpa/inet.h>
 #include	<sys/ipc.h>
 #include	<sys/shm.h>
-
-#define DB(x) x
+#include	<time.h>
 
 #define timercmp(a, b, CMP) \
  (((a)->tv_sec == (b)->tv_sec) ? \
@@ -79,3 +80,6 @@ in_port_t	dbInPort;
 in_port_t	dbOutPort;
 in_port_t	MonitorPort;
 
+FILE	*logfile;
+time_t	now;
+
